#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 typed-process
version:              0.2.13.0
visibility:           public
id:                   typed-process-0.2.13.0-40GtvANGP6yKk97Fq1akCj
key:                  typed-process-0.2.13.0-40GtvANGP6yKk97Fq1akCj
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/typed-process
synopsis:             Run external processes, with strong typing of streams
description:
    Please see the tutorial at <https://github.com/fpco/typed-process#readme>

category:             System
abi:                  490360d3b2a1d16aa6cd9e0655170b92
exposed:              True
exposed-modules:      System.Process.Typed System.Process.Typed.Internal
hidden-modules:       Paths_typed_process
import-dirs:          /usr/lib/ghc-9.6.6/site-local/typed-process-0.2.13.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/typed-process-0.2.13.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/typed-process-0.2.13.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-typed-process
hs-libraries:         HStyped-process-0.2.13.0-40GtvANGP6yKk97Fq1akCj
depends:
    async-2.2.5-BExe3HBSFHr8hii1cT1bvS base-4.18.2.1
    bytestring-0.11.5.3 process-1.6.19.0 stm-2.5.1.0 text-2.0.2
    transformers-0.6.1.0 unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:
    /usr/share/doc/haskell-typed-process/html/typed-process.haddock

haddock-html:         /usr/share/doc/haskell-typed-process/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

